@@ -75,7 +75,6 @@ qDF <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = "data.frame
   X
 }
 
-
 qDT <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = c("data.table", "data.frame")) {
   if(is.atomic(X)) {
     d <- dim(X)
@@ -95,10 +94,10 @@ qDT <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = c("data.tab
         attr(res, "row.names") <- .set_row_names(length(dn[[1L]]))
       } else res <- .Call(Cpp_mctl, X, TRUE, 2L)
       oldClass(res) <- if(length(class)) class else c("data.table", "data.frame")
-      if(!keep.attr) return(res)
+      if(!keep.attr) return(alc(res))
       ax <- attributes(X)
       axoth <- names(ax) %!in% c("dim", "dimnames", "class")
-      if(any(axoth)) return(addAttributes(res, ax[axoth])) else return(res)
+      return(alc(if(any(axoth)) addAttributes(res, ax[axoth]) else res))
     }
     if(isFALSE(row.names.col) || is.null(nam <- names(X))) {
       res <- `names<-`(list(X), l1orlst(as.character(substitute(X))))
@@ -107,7 +106,7 @@ qDT <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = c("data.tab
       names(res) <- c(if(is.character(row.names.col)) row.names.col[1L] else "row.names", l1orlst(as.character(substitute(X))))
     }
     attr(res, "row.names") <- .set_row_names(length(X))
-    return(`oldClass<-`(res, if(length(class)) class else c("data.table", "data.frame")))
+    return(alc(`oldClass<-`(res, if(length(class)) class else c("data.table", "data.frame"))))
   }
   if(keep.attr) {
     # if(all(class(X) == class)) return(X) # better adjust rows ? -> yes, row.names.col should always work !
@@ -118,7 +117,7 @@ qDT <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = c("data.tab
       ax[["names"]] <- c(if(is.character(row.names.col)) row.names.col[1L] else "row.names", ax[["names"]])
       setattributes(X, ax)
     }
-    if(!length(class) && inherits(X, c("data.table", "data.frame"))) return(X)
+    if(!length(class) && inherits(X, c("data.table", "data.frame"))) return(alc(X))
     attr(X, "row.names") <- .set_row_names(length(.subset2(X, 1L)))
   } else {
     nam <- attr(X, "names")
@@ -133,7 +132,7 @@ qDT <- function(X, row.names.col = FALSE, keep.attr = FALSE, class = c("data.tab
     attr(X, "row.names") <- .set_row_names(length(X[[1L]]))
   }
   oldClass(X) <- if(length(class)) class else c("data.table", "data.frame")
-  X
+  return(alc(X))
 }
 
 qTBL <- function(X, row.names.col = FALSE, keep.attr = FALSE)
